@@ -1,5 +1,7 @@
 package XML::XPathScript::Template;
-
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: XML::XPathScript transformation template 
+$XML::XPathScript::Template::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -13,8 +15,6 @@ use Scalar::Util qw/ refaddr /;
 use overload '&{}'  => \&_overload_func,
              q{""}  => \&_overload_quote;
 
-our $VERSION = '1.54';
-
 sub new {
    my( $class ) = @_;
 
@@ -169,16 +169,18 @@ sub _overload_quote {
 
 1;
 
-__END__
+=pod
 
-#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-#  Module Documentation
-#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+=encoding UTF-8
 
 =head1 NAME
 
 XML::XPathScript::Template - XML::XPathScript transformation template 
 
+=head1 VERSION
+
+version 1.55
+
 =head1 SYNOPSIS
 
     <%
@@ -207,7 +209,6 @@ are performed on the tags of a document as they are processed.
 The template of a stylesheet can be accessed via variables 
 I<$t>, I<$template> and I<$XML::XPathScript::trans>.
 
-
 =head1 METHODS
 
 =head2 new
@@ -216,7 +217,7 @@ I<$t>, I<$template> and I<$XML::XPathScript::trans>.
 
 Creates and returns a new, empty template.
 
-=head2  set
+=head2 set
 
     $template->set( $tag, \%attributes )
     $template->set( \@tags , \%attributes )
@@ -276,7 +277,6 @@ Example:
     # also modifies 'foo'
     $template->set( 'bar' => { pre => '<u>' } );  
 
-
 =head2 is_alias
 
     @aliases = $template->is_alias( $tag )
@@ -330,7 +330,6 @@ Example:
     #    }
     # };
 
-
 =head2 namespace
 
     my $subtemplate = $template->namespace( $uri );
@@ -427,15 +426,38 @@ access methods.
         $t->alias( important => alert );
     %>
 
-=head1 BUGS 
+=head1 AUTHORS
 
-Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
-or via the web interface at 
-http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
+=over 4
 
-=head1 AUTHOR
+=item *
 
 Yanick Champoux <yanick@cpan.org>
 
+=item *
+
+Dominique Quatravaux <domq@cpan.org>
+
+=item *
+
+Matt Sergeant <matt@sergeant.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018, 2008, 2007 by Matt Sergeant.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+__END__
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+#  Module Documentation
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+
+
